@@ -1,13 +1,11 @@
 # This file is part of Tryton.  The COPYRIGHT file at the top level of
 # this repository contains the full copyright notices and license terms.
-from trytond import backend
 from trytond.i18n import gettext
 from trytond.model import ModelSQL, fields
-from trytond.pool import Pool, PoolMeta
-from trytond.transaction import Transaction
-from trytond.pyson import Eval
-from trytond.tools.multivalue import migrate_property
 from trytond.modules.company.model import CompanyValueMixin
+from trytond.pool import Pool, PoolMeta
+from trytond.pyson import Eval
+from trytond.transaction import Transaction
 
 from .exceptions import CreditLimitError, CreditLimitWarning
 
@@ -16,13 +14,11 @@ class Party(metaclass=PoolMeta):
     __name__ = 'party.party'
 
     credit_amount = fields.Function(fields.Numeric('Credit Amount',
-            digits=(16, Eval('credit_limit_digits', 2)),
-            depends=['credit_limit_digits']),
+            digits=(16, Eval('credit_limit_digits', 2))),
         'get_credit_amount')
     credit_limit_amount = fields.MultiValue(fields.Numeric(
             'Credit Limit Amount',
-            digits=(16, Eval('credit_limit_digits', 2)),
-            depends=['credit_limit_digits']))
+            digits=(16, Eval('credit_limit_digits', 2))))
     credit_limit_digits = fields.Function(fields.Integer('Currency Digits'),
         'get_credit_limit_digits')
     credit_limit_amounts = fields.One2Many(
@@ -80,7 +76,7 @@ class Party(metaclass=PoolMeta):
 
         for model in self._credit_limit_to_lock():
             Model = pool.get(model)
-            Transaction().database.lock(Transaction().connection, Model._table)
+            Model.lock()
         if self.credit_limit_amount < self.credit_amount + amount:
             company = Company(Transaction().context.get('company'))
             lang = Lang.get()
@@ -134,35 +130,16 @@ class PartyCreditLimitAmount(ModelSQL, CompanyValueMixin):
     "Party Credit Limit Amount"
     __name__ = 'party.party.credit_limit_amount'
     party = fields.Many2One(
-        'party.party', "Party", ondelete='CASCADE', select=True,
+        'party.party', "Party", ondelete='CASCADE',
         context={
             'company': Eval('company', -1),
             },
-        depends=['company'])
+        depends={'company'})
     credit_limit_amount = fields.Numeric(
-        "Credit Limit Amount", digits=(16, Eval('credit_limit_digits', 2)),
-        depends=['credit_limit_digits'])
+        "Credit Limit Amount", digits=(16, Eval('credit_limit_digits', 2)))
     credit_limit_digits = fields.Function(fields.Integer('Currency Digits'),
         'on_change_with_credit_limit_digits')
 
-    @classmethod
-    def __register__(cls, module_name):
-        exist = backend.TableHandler.table_exist(cls._table)
-
-        super(PartyCreditLimitAmount, cls).__register__(module_name)
-
-        if not exist:
-            cls._migrate_property([], [], [])
-
-    @classmethod
-    def _migrate_property(cls, field_names, value_names, fields):
-        field_names.append('credit_limit_amount')
-        value_names.append('credit_limit_amount')
-        fields.append('company')
-        migrate_property(
-            'party.party', field_names, cls, value_names,
-            parent='party', fields=fields)
-
     @fields.depends('company')
     def on_change_with_credit_limit_digits(self, name=None):
         if self.company:
